\name{statComputing}
\alias{statComputing}
\title{Computing Summary Statistics}
\description{
	Computing summary statistics, including \eqn{\theta_w}, \eqn{\theta_\pi}, \eqn{\theta_h}, 
	\eqn{\theta_l}, Tajima's D, Fay and Wu's H, MFDM, iHH in sliding windows 
	for each sample in a ms/msms file or the sample in a fasta file.
}
\usage{
statComputing(file, win_size=0.2, win_step=0.2, y=0)
}
\arguments{
	\item{file}{the name of the input file, must be a ms/msms result file or a fasta file.}
	\item{win_size}{the size of the sliding window, must be a numeric value 
	between 0 and 0.5. Default value is 0.2}
	\item{win_step}{the step size of the sliding window, must be a numeric value 
	> 0. Default value is 0.2}
	\item{y}{The indicator variable indicates wether the sample(s) in the file is(are) 
	selected or neutral. 0(default) indicates neutral evolution. 1 indicates selection.}
}

\value{
	This function returns a data frame which stores all the summary statistics computed 
	by this function. Each row represents a sample. Each column(except the last column) 
	stores one summary statistics in one sliding window, and the last column stores the 
	indictor variable y.
}

\details{
	This function computes different summary statistics in sliding windows from 
	population DNA samples(Lin et al. 2011). 

	The file containing population DNA samples must be ms result format(Hudson 2002), 
	msms result format(Ewing and Hermisson 2010), which is almost the same as ms format, 
	and fasta format(Pearson and Lipman 1988).

	If the file is in fasta format, one of the samples must be outgroup and contains the 
	string "outgroup" in its name line.

	The summary statistics are computed in sliding windows in two different forms.
	\eqn{\theta_w}(Watterson 1975), \eqn{\theta_\pi}(Tajima 1983), 
	\eqn{\theta_h}(Fay and Wu 2000), \eqn{\theta_l}(Zeng et al. 2006), 
	Tajima's D(Tajima 1989), Fay and Wu's H(Fay and Wu 2000, Zeng et al. 2006), 
	MFDM(Li 2011) will be computed in each window when the sliding window slides from 
	the left end to the right end of the sequence region. 
	iHH(Sabeti et al. 2002, Voight et al. 2006) will be computed in each window when 
	2 windows extends from the middle point to the two ends of the sequence region.

	For example, if win_size=0.2 and win_step=0.1, all the summary statistics except iHH 
	will be computed in each of the following regions: 0~0.2, 0.1~0.3, 0.2~0.4, 0.3~0.5, 
	0.4~0.6, 0.5~0.7, 0.6~0.8, 0.7~0.9, 0.8~1.0.
	iHH is integrated EHH, which will be integrated from the middle point to both left 
	and right. In this example, iHH will be integrated from 0.5 to 0.4, 0.3, 0.2, 0.1 and 0 
	on the left and from 0.5 to 0.6, 0.7, 0.8, 0.9 and 1.0 on the left.
	Thus, we will have 9(sliding windows)*7(summary statistics except iHH) + 10(iHHs)=73 
	values of different summary statistics.

}

\author{
	Kao Lin, Zongfeng Yang and Haipeng Li
}

\references{
	G. Ewing and J. Hermisson(2010) MSMS: A coalescent simulation program including
	recombination, demographic structure, and selection at a single locus.
	Bioinformatics 26:2064-2065.

	J.C. Fay and C.I. Wu(2000) Hitchhiking under positive Darwinian selection.
	Genetics 155:1405-1413.

	R.R. Hudson(2002) Generating samples under a Wright-Fisher neutral model.
	Bioinformatics 18:337-338.

	H. Li(2011) A new test for detecting recent positive selection that is free from 
	the coufounding impacts of demography. Mol Biol Evol 28:365-375.

	K. Lin, H. Li, C. Schloetterer and A. Futschik(2011) Distinguishing 
	positive selection from neutral evolution: boosting the performance of summary statistics.
	Genetics 187: 229-244.
	
	W.R. Pearson and D.J. Lipman(1988) Improved tools for biological sequence comparison.
	Proc Natl Acad Sci U S A 85:2444-2448.

	P.C. Sabeti, D.E. Reich, J.M. Higgins, H.Z.P. Levine, D.J. Richter et al.(2002)
	Detecting recent positive selection in the human genome from haplotype structure.
	Nature 419:832-837.

	F. Tajima(1983) Evolutionary relationship of DNA sequences in finite populations.
	Genetics 105:437-460.

	F. Tajima(1989) Statistical method for testing the nuetral mutation hypothesis by DNA 
	polymorphism. Genetics 123:585-595.

	B.F. Voight, S. Kudaravalli, X. Wen and J.K. Pritchard(2006) A map of recent positive 
	selection in the human genome. PLoS Biol. 4:e72.
	
	G.A. Watterson(1975) On the number of segregating sites in genetical models 
	without recombination. Thero. Popul. Biol. 7:256-276.

	K. Zeng, S. Shi and C.I. Wu(2006) Statistical tests for detecting positive selection
	by utilizing high-frequency variants. Genetics 174:1431-1439.	
}

\examples{
# ms format
ms <- system.file("extdata/ms.out", package="evolBoosting")
train1 <- statComputing(ms, 0.2, 0.2, y = 0)

# fasta format
fasta <- system.file("extdata/test.fasta", package="evolBoosting")
test <- statComputing(fasta)
}
